@@ -1,22 +1,22 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Authors: Chris Toshok <toshok@ximian.com>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Copyright (C) 2003 Ximian, Inc. (www.ximian.com)
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>  
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Authors:
+ *		Chris Toshok <toshok@ximian.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
@@ -72,6 +72,7 @@ common_location [] =
 #define MSN_ICON          "im-msn"
 #define YAHOO_ICON        "im-yahoo"
 #define GADUGADU_ICON	    "im-gadugadu"
+#define SKYPE_ICON	    "stock_people"
 #define VIDEOCONF_ICON    "stock_video-conferencing"
 
 #define MAX_COMPACT_IMAGE_DIMENSION 48
@@ -525,7 +526,7 @@ get_email_location (EVCardAttribute *attr)
 			return _(common_location [i].pretty_name);
 	}
 
-	return NULL;
+	return _("Other");
 }
 
 static void
@@ -618,6 +619,7 @@ render_contact (GtkHTMLStream *html_stream, EContact *contact)
 	accum_multival_attribute (accum, contact, _("MSN"), E_CONTACT_IM_MSN, MSN_ICON, 0);
 	accum_multival_attribute (accum, contact, _("Yahoo"), E_CONTACT_IM_YAHOO, YAHOO_ICON, 0);
 	accum_multival_attribute (accum, contact, _("Gadu-Gadu"), E_CONTACT_IM_GADUGADU, GADUGADU_ICON, 0);
+	accum_multival_attribute (accum, contact, _("Skype"), E_CONTACT_IM_SKYPE, SKYPE_ICON, 0);
 
 	if (accum->len > 0)
 		gtk_html_stream_printf (html_stream, "%s", accum->str);
@@ -751,14 +753,33 @@ eab_contact_display_render_compact (EABContactDisplay *display, EContact *contac
 		const char *str;
 		char *html;
 		EContactPhoto *photo;
+		guint bg_frame = 0x000000, bg_body = 0xEEEEEE;
+		GtkStyle *style;
+
+		style = gtk_widget_get_style (GTK_WIDGET (display));
+		if (style) {
+			gushort r, g, b;
+
+			r = style->black.red >> 8;
+			g = style->black.green >> 8;
+			b = style->black.blue >> 8;
+			bg_frame = ((r << 16) | (g << 8) | b) & 0xffffff;
+
+			#define DARKER(a) (((a) >= 0x22) ? ((a) - 0x22) : 0)
+			r = DARKER (style->bg[GTK_STATE_NORMAL].red >> 8);
+			g = DARKER (style->bg[GTK_STATE_NORMAL].green >> 8);
+			b = DARKER (style->bg[GTK_STATE_NORMAL].blue >> 8);
+			bg_body = ((r << 16) | (g << 8) | b) & 0xffffff;
+			#undef DARKER
+		}
 
 		gtk_html_stream_printf (html_stream,
-					"<table width=\"100%%\" cellpadding=1 cellspacing=0 bgcolor=\"#000000\">"
+					"<table width=\"100%%\" cellpadding=1 cellspacing=0 bgcolor=\"#%06X\">"
 					"<tr><td valign=\"top\">"
-					"<table width=\"100%%\" cellpadding=0 cellspacing=0 bgcolor=\"#eeeeee\">"
+					"<table width=\"100%%\" cellpadding=0 cellspacing=0 bgcolor=\"#%06X\">"
 					"<tr><td valign=\"top\">"
 					"<table>"
-					"<tr><td valign=\"top\">");
+					"<tr><td valign=\"top\">", bg_frame, bg_body);
 
 		photo = e_contact_get (contact, E_CONTACT_PHOTO);
 		if (!photo)
