@@ -138,6 +138,7 @@ static const gchar *ui =
 "  <menubar action='main-menu'>"
 "    <menu action='file-menu'>"
 "      <menuitem action='save'/>"
+"      <menuitem action='print'/>"
 "      <menuitem action='close'/>"
 "    </menu>"
 "    <menu action='edit-menu'>"
@@ -159,6 +160,7 @@ static const gchar *ui =
 "  </menubar>"
 "  <toolbar name='main-toolbar'>"
 "    <toolitem action='save'/>"
+"    <toolitem action='print'/>"
 "    <toolitem action='close'/>"
 "    <separator/>"
 "    <toolitem action='attach'/>"
@@ -1100,6 +1102,24 @@ action_print_preview_cb (GtkAction *action,
 	g_object_unref (comp);
 }
 
+static gboolean
+remove_event_dialog (ECal *client,
+		     ECalComponent *comp,
+		     GtkWindow *parent)
+{
+	GtkWidget *dialog;
+	gboolean ret;
+
+	g_return_val_if_fail (E_IS_CAL_COMPONENT (comp), TRUE);
+
+	dialog = gtk_message_dialog_new (parent, 0, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, "%s", _("Keep original item?"));
+	gtk_window_set_resizable (GTK_WINDOW (dialog), TRUE);
+	ret = gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES;
+	gtk_widget_destroy (dialog);
+
+	return ret;
+}
+
 static void
 action_save_cb (GtkAction *action,
                 CompEditor *editor)
@@ -1151,9 +1171,33 @@ action_save_cb (GtkAction *action,
 	if (!text.value)
 		if (!send_component_prompt_subject ((GtkWindow *) editor, priv->client, priv->comp))
 			return;
-	if (save_comp_with_send (editor))
-		close_dialog (editor);
 
+	if (save_comp_with_send (editor)) {
+		CompEditorFlags flags;
+		gboolean delegate;
+
+		flags = comp_editor_get_flags (editor);
+		delegate = flags & COMP_EDITOR_DELEGATE;
+
+		if (delegate && !remove_event_dialog (priv->client, priv->comp, GTK_WINDOW (editor))) {
+			const char *uid = NULL; 
+			GError *error = NULL;
+
+			e_cal_component_get_uid (priv->comp, &uid);
+
+			if (e_cal_component_is_instance (priv->comp) || e_cal_component_has_recurrences (priv->comp)) {
+				gchar *rid;
+				rid = e_cal_component_get_recurid_as_string (priv->comp);
+				e_cal_remove_object_with_mod (priv->client, uid, rid, priv->mod, &error);
+				g_free (rid);
+			} else
+				e_cal_remove_object (priv->client, uid, &error);
+
+			g_clear_error (&error);
+		}
+	}
+
+	close_dialog (editor);
 }
 
 static void
@@ -1297,7 +1341,7 @@ static GtkActionEntry core_entries[] = {
 	{ "print",
 	  GTK_STOCK_PRINT,
 	  NULL,
-	  NULL,
+	  "<Control>p",
 	  NULL,
 	  G_CALLBACK (action_print_cb) },
 
@@ -3046,7 +3090,8 @@ real_send_comp (CompEditor *editor, ECalComponentItipMethod method)
 			set_attendees_for_delegation (send_comp, address, method);
 	}
 
-	if (!e_cal_component_has_attachments (priv->comp)) {
+		if (!e_cal_component_has_attachments (priv->comp) 
+		 || e_cal_get_static_capability (priv->client, CAL_STATIC_CAPABILITY_CREATE_MESSAGES)) {
 		if (itip_send_comp (method, send_comp, priv->client,
 					NULL, NULL, users)) {
 			g_object_unref (send_comp);
