@@ -139,7 +139,7 @@ temp_save_part(CamelMimePart *part, char *path, gboolean file)
 		usepath = g_strjoin (NULL, "file://", path, NULL);
 
 	wrapper = camel_medium_get_content_object (CAMEL_MEDIUM (part));
-	stream = camel_stream_vfs_new_with_uri (usepath, CAMEL_STREAM_VFS_CREATE);
+	stream = camel_stream_vfs_new_with_uri (path, CAMEL_STREAM_VFS_CREATE);
 
 	if (usepath != path)
 		g_free (usepath);
@@ -397,17 +397,18 @@ ecalp_standard_menu_factory (EPopup *ecalp, void *data)
                 for (cp = mime_type; *cp != '\0'; cp++)
                         *cp = g_ascii_tolower (*cp);
 
-		/* TODO: g_app_info_get_all_for_type expects content_type, not a mime_type, thus it will work fine
-		    on Linux/Unix systems, but not on Win32. They will add hopefully some function to convert between
-		    these two soon. */
-		apps = g_app_info_get_all_for_type (mime_type);
+		cp = g_content_type_from_mime_type (mime_type);
+		apps = g_app_info_get_all_for_type (cp ? cp : mime_type);
+		g_free (cp);
 
-		if (apps == NULL || strcmp(mime_type, "application/octet-stream") == 0) {
+		if (apps == NULL && strcmp(mime_type, "application/octet-stream") == 0) {
 			if (filename) {
 				gchar *name_type;
 
 				name_type = e_util_guess_mime_type (filename, FALSE);
-				apps = g_list_concat (g_app_info_get_all_for_type (name_type), apps);
+				cp = g_content_type_from_mime_type (name_type);
+				apps = g_app_info_get_all_for_type (cp ? cp : name_type);
+				g_free (cp);
 				g_free (name_type);
 			}
 		}
